lcvtoolbox.core.schemas.CvatApiAttributeDefinition
==================================================

.. currentmodule:: lcvtoolbox.core.schemas

.. autoclass:: CvatApiAttributeDefinition
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiAttributeDefinition.__init__
      ~CvatApiAttributeDefinition.construct
      ~CvatApiAttributeDefinition.copy
      ~CvatApiAttributeDefinition.dict
      ~CvatApiAttributeDefinition.from_orm
      ~CvatApiAttributeDefinition.json
      ~CvatApiAttributeDefinition.model_construct
      ~CvatApiAttributeDefinition.model_copy
      ~CvatApiAttributeDefinition.model_dump
      ~CvatApiAttributeDefinition.model_dump_json
      ~CvatApiAttributeDefinition.model_json_schema
      ~CvatApiAttributeDefinition.model_parametrized_name
      ~CvatApiAttributeDefinition.model_post_init
      ~CvatApiAttributeDefinition.model_rebuild
      ~CvatApiAttributeDefinition.model_validate
      ~CvatApiAttributeDefinition.model_validate_json
      ~CvatApiAttributeDefinition.model_validate_strings
      ~CvatApiAttributeDefinition.parse_file
      ~CvatApiAttributeDefinition.parse_obj
      ~CvatApiAttributeDefinition.parse_raw
      ~CvatApiAttributeDefinition.schema
      ~CvatApiAttributeDefinition.schema_json
      ~CvatApiAttributeDefinition.update_forward_refs
      ~CvatApiAttributeDefinition.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiAttributeDefinition.model_computed_fields
      ~CvatApiAttributeDefinition.model_config
      ~CvatApiAttributeDefinition.model_extra
      ~CvatApiAttributeDefinition.model_fields
      ~CvatApiAttributeDefinition.model_fields_set
      ~CvatApiAttributeDefinition.id
      ~CvatApiAttributeDefinition.name
      ~CvatApiAttributeDefinition.mutable
      ~CvatApiAttributeDefinition.input_type
      ~CvatApiAttributeDefinition.values
      ~CvatApiAttributeDefinition.default_value
   
   